@@ -6,6 +6,9 @@ use Net::Braintree::ErrorCodes::CreditCard;
 use Net::Braintree::ErrorCodes::CreditCard::Options;
 use Net::Braintree::ErrorCodes::Customer;
 use Net::Braintree::ErrorCodes::Descriptor;
+use Net::Braintree::ErrorCodes::MerchantAccount;
+use Net::Braintree::ErrorCodes::MerchantAccount::ApplicantDetails;
+use Net::Braintree::ErrorCodes::MerchantAccount::ApplicantDetails::Address;
 use Net::Braintree::ErrorCodes::SettlementBatchSummary;
 use Net::Braintree::ErrorCodes::Subscription;
 use Net::Braintree::ErrorCodes::Subscription::Modification;
